@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  * Original C# file
  * (C) 2006 Ryan Lortie <desrt@desrt.ca>
@@ -55,9 +56,9 @@ namespace fixedwidth {
   {
     return "";
   }
-  const char * FixedWidthModule::category() const
+  int FixedWidthModule::category() const
   {
-    return "Formatting";
+    return gnote::ADDIN_CATEGORY_FORMATTING;
   }
   const char * FixedWidthModule::version() const
   {
