@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -103,6 +104,7 @@ private:
   RemoteControl     *m_remote_control;
 };
 
+class RemoteControlClient;
 
 class GnoteCommandLine
 {
@@ -128,6 +130,8 @@ public:
                              GError **error);
 private:
   void        print_version();
+  bool        display_note(RemoteControlClient * remote,
+                           std::string uri);
 
   GOptionContext *m_context;
 
