@@ -1,6 +1,8 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010-2011 Aurimas Cernius
+ * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -27,6 +29,7 @@
 #include <boost/format.hpp>
 
 #include <glibmm/i18n.h>
+#include <gtkmm/separatormenuitem.h>
 
 #include "sharp/string.hpp"
 #include "debug.hpp"
@@ -228,7 +231,7 @@ namespace gnote {
     }
 
     DBG_OUT ("Renaming note from %s to %s", get_note()->get_title().c_str(), title.c_str());
-    get_note()->set_title(title);
+    get_note()->set_title(title, true);
     return true;
   }
 
@@ -430,6 +433,8 @@ namespace gnote {
 
     get_buffer()->signal_insert().connect(
       sigc::mem_fun(*this, &NoteUrlWatcher::on_insert_text));
+    get_buffer()->signal_apply_tag().connect(
+      sigc::mem_fun(*this, &NoteUrlWatcher::on_apply_tag));
     get_buffer()->signal_erase().connect(
       sigc::mem_fun(*this, &NoteUrlWatcher::on_delete_range));
 
@@ -455,17 +460,18 @@ namespace gnote {
     // Simple url massaging.  Add to 'http://' to the front
     // of www.foo.com, 'mailto:' to alex@foo.com, 'file://'
     // to /home/alex/foo.
-    if (sharp::string_starts_with(url, "www.")) {
+    if (Glib::str_has_prefix(url, "www.")) {
       url = "http://" + url;
     }
-    else if (sharp::string_starts_with(url, "/") &&
+    else if (Glib::str_has_prefix(url, "/") &&
              sharp::string_last_index_of(url, "/") > 1) {
       url = "file://" + url;
     }
-    else if (sharp::string_starts_with(url, "~/")) {
+    else if (Glib::str_has_prefix(url, "~/")) {
       const char * home = getenv("HOME");
       if(home) {
-        url = std::string("file://") + home + sharp::string_substring(url, 2);
+        url = std::string("file://") + home + "/" +
+          sharp::string_substring(url, 2);
       }
     }
     else if (sharp::string_match_iregex(url, 
@@ -543,6 +549,20 @@ namespace gnote {
     apply_url_to_block (start, pos);
   }
 
+  void NoteUrlWatcher::on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & tag,
+                                    const Gtk::TextIter & start, const Gtk::TextIter & end)
+  {
+    if(tag != m_url_tag)
+      return;
+    std::string s(start.get_slice(end));
+    std::string match1;
+    const char *p = s.c_str();
+    pcrecpp::StringPiece input(p);
+    if(!m_regex.FindAndConsume(&input, &match1))
+      get_buffer()->remove_tag (m_url_tag, start, end);
+  }
+
+
 
   bool NoteUrlWatcher::on_button_press(GdkEventButton *ev)
   {
@@ -669,6 +689,8 @@ namespace gnote {
     }
     get_buffer()->signal_insert().connect(
       sigc::mem_fun(*this, &NoteLinkWatcher::on_insert_text));
+    get_buffer()->signal_apply_tag().connect(
+      sigc::mem_fun(*this, &NoteLinkWatcher::on_apply_tag));
     get_buffer()->signal_erase().connect(
       sigc::mem_fun(*this, &NoteLinkWatcher::on_delete_range));
   }
@@ -732,30 +754,6 @@ namespace gnote {
     if (contains_text (renamed->get_title())) {
       highlight_note_in_block (renamed, get_buffer()->begin(), get_buffer()->end());
     }
-
-    if (!contains_text (old_title)) {
-      return;
-    }
-
-    std::string old_title_lower = sharp::string_to_lower(old_title);
-
-    // Replace existing links with the new title.
-    utils::TextTagEnumerator enumerator(get_buffer(), m_link_tag);
-    while(enumerator.move_next()) {
-      const utils::TextRange & range(enumerator.current());
-      if (sharp::string_to_lower(range.text()) != old_title_lower) {
-        continue;
-      }
-
-      DBG_OUT ("Replacing '%s' with '%s'",
-               range.text().c_str(), renamed->get_title().c_str());
-
-      Gtk::TextIter start_iter = range.start();
-      Gtk::TextIter end_iter = range.end();
-      end_iter = get_buffer()->erase (start_iter, end_iter);
-      start_iter = range.start();
-      get_buffer()->insert_with_tag(start_iter, renamed->get_title(), m_link_tag);
-    }
   }
 
   
@@ -882,6 +880,16 @@ namespace gnote {
   }
 
 
+  void NoteLinkWatcher::on_apply_tag(const Glib::RefPtr<Gtk::TextBuffer::Tag> & tag,
+                                     const Gtk::TextIter & start, const Gtk::TextIter &end)
+  {
+    std::string link_name = start.get_text (end);
+    Note::Ptr link = manager().find (link_name);
+    if(!link)
+        unhighlight_in_block(start, end);
+  }
+
+
   bool NoteLinkWatcher::open_or_create_link(const Gtk::TextIter & start,
                                             const Gtk::TextIter & end)
   {
